/*----------------------------------------------------------------------------
 * Name:    LED.c
 * Purpose: low level LED functions
 * Note(s):
 *----------------------------------------------------------------------------
 * All files for ADuCM362 provided by ADI, including this file, are
 * provided  as is without warranty of any kind, either expressed or implied.
 * The user assumes any and all risk from the use of this code.
 * It is the responsibility of the person integrating this code into an application
 * to ensure that the resulting application performs as required and is safe.
 *----------------------------------------------------------------------------*/

#include <ADuCM362.h>
#include "LED.h"

const uint32_t led_mask[] = { 1UL << 3 };

/*----------------------------------------------------------------------------
  initialize LED Pins (GPIO2.0..1)
 *----------------------------------------------------------------------------*/
void LED_Init (void) {

  /* configure GPIO as output */
  pADI_GP1->GPOEN  |=  (led_mask[0] );              /* GPIO1.3 is output      */

  pADI_GP1->GPSET   =  led_mask[0];                 /* switch LED off         */

}

/*----------------------------------------------------------------------------
  Function that turns on requested LED
 *----------------------------------------------------------------------------*/
void LED_On (unsigned int num) {

  if (num < LED_NUM) {
    pADI_GP1->GPCLR = led_mask[0];
  }
}

/*----------------------------------------------------------------------------
  Function that turns off requested LED
 *----------------------------------------------------------------------------*/
void LED_Off (unsigned int num) {

  if (num < LED_NUM) {
    pADI_GP1->GPSET = led_mask[0];
  }
}

/*----------------------------------------------------------------------------
  Function that outputs value to LEDs
 *----------------------------------------------------------------------------*/
void LED_Out(unsigned int value) {
  int i;

  for (i = 0; i < LED_NUM; i++) {
    if (value & (1<<i)) {
      LED_On (i);
    } else {
      LED_Off(i);
    }
  }
}
